@@ -2,6 +2,7 @@ import errno
 import json
 import shutil
 import subprocess
+import warnings
 
 from . import constants
 from . import errors
@@ -18,10 +19,9 @@ class Store:
         self.exe = shutil.which(self.program)
         self.environment = environment
         if self.exe is None:
-            raise errors.InitializationError(
-                '{} not installed or not available in PATH'.format(
-                    self.program
-                )
+            warnings.warn(
+                f'{self.program} not installed or not available in PATH',
+                stacklevel=1,
             )
 
     def get(self, server):
@@ -70,6 +70,10 @@ class Store:
         return json.loads(data.decode('utf-8'))
 
     def _execute(self, subcmd, data_input):
+        if self.exe is None:
+            raise errors.StoreError(
+                f'{self.program} not installed or not available in PATH'
+            )
         output = None
         env = create_environment_dict(self.environment)
         try:
@@ -77,18 +81,14 @@ class Store:
                 [self.exe, subcmd], input=data_input, env=env,
             )
         except subprocess.CalledProcessError as e:
-            raise errors.process_store_error(e, self.program)
+            raise errors.process_store_error(e, self.program) from e
         except OSError as e:
             if e.errno == errno.ENOENT:
                 raise errors.StoreError(
-                    '{} not installed or not available in PATH'.format(
-                        self.program
-                    )
-                )
+                    f'{self.program} not installed or not available in PATH'
+                ) from e
             else:
                 raise errors.StoreError(
-                    'Unexpected OS error "{}", errno={}'.format(
-                        e.strerror, e.errno
-                    )
-                )
+                    f'Unexpected OS error "{e.strerror}", errno={e.errno}'
+                ) from e
         return output
