@@ -1,5 +1,6 @@
-# flake8: noqa
-from .containers import ContainerConfig, HostConfig, LogConfig, Ulimit
+from .containers import (
+    ContainerConfig, HostConfig, LogConfig, Ulimit, DeviceRequest
+)
 from .daemon import CancellableStream
 from .healthcheck import Healthcheck
 from .networks import EndpointConfig, IPAMConfig, IPAMPool, NetworkingConfig
@@ -7,6 +8,6 @@ from .services import (
     ConfigReference, ContainerSpec, DNSConfig, DriverConfig, EndpointSpec,
     Mount, Placement, PlacementPreference, Privileges, Resources,
     RestartPolicy, RollbackConfig, SecretReference, ServiceMode, TaskTemplate,
-    UpdateConfig
+    UpdateConfig, NetworkAttachmentConfig
 )
 from .swarm import SwarmSpec, SwarmExternalCA
